Package: graphonmix
Type: Package
Title: Generates Dense and Sparse Graphs using Graphon Extensions
Version: 0.1.1
Authors@R: c(
   person("Sevvandi", "Kandanaarachchi", email = "sevvandik@gmail.com",
  role = c("aut", "cre"), comment = c(ORCID = "0000-0002-0337-0395"))
    )
Maintainer: Sevvandi Kandanaarachchi <sevvandik@gmail.com>
Description: Generates dense or sparse graphs using graphon mixtures and graphettes. Graphon mixtures uses two graphons U and W to generate graphs. Sparse graphs are generated in this case using the inverse line graph (root) operation. Graphettes have 3 components, the graphon W, a real-valued sequence and a graph edit function. Both techniques can generate dense or sparse graphs. Kandanaarachchi and Ong (2026) <doi:10.48550/arXiv.2505.13864>, Wijesinghe et al (2026) <doi:10.48550/arXiv.2602.23566>.
License: GPL (>= 3)
Encoding: UTF-8
RoxygenNote: 7.3.3
Imports: ggplot2, igraph, imager, stats
Suggests: gridExtra, knitr, rmarkdown
VignetteBuilder: knitr
URL: https://sevvandi.github.io/graphonmix/
NeedsCompilation: no
Packaged: 2026-06-12 06:20:37 UTC; kan092
Author: Sevvandi Kandanaarachchi [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-0337-0395>)
Repository: CRAN
Date/Publication: 2026-06-12 07:50:02 UTC
Built: R 4.6.0; ; 2026-06-12 11:03:40 UTC; unix
