# Generated by roxygen2: do not edit by hand

S3method(autoplot,extract_sparse)
S3method(autoplot,separate_dense_and_sparse)
export(autoplot)
export(create_exp_matrix)
export(empirical_graphon)
export(extract_sparse)
export(generate_star_union)
export(graph_join)
export(line_graphon)
export(plot_graphon)
export(predict_hubs)
export(ring_graphon)
export(sample_graphette)
export(sample_graphon)
export(sample_mixed_graph)
export(sample_sparse_graphon)
export(sbm_graphon)
export(scale_graphon)
export(separate_dense_and_sparse)
export(star_f1)
export(star_f2)
export(star_f3)
export(star_f4)
export(star_f5)
importFrom(ggplot2,aes)
importFrom(ggplot2,autoplot)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_raster)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,scale_fill_gradientn)
importFrom(ggplot2,scale_y_reverse)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(ggplot2,xlab)
importFrom(ggplot2,ylab)
importFrom(igraph,"%du%")
importFrom(igraph,degree)
importFrom(igraph,ecount)
importFrom(igraph,vcount)
importFrom(stats,coef)
importFrom(stats,lm)
importFrom(stats,median)
importFrom(stats,predict)
