#' @importFrom ggplot2 ggplot aes geom_raster xlab ylab geom_point geom_line scale_y_reverse
#' @importFrom ggplot2 autoplot scale_fill_gradientn theme theme_bw element_blank
#' @importFrom stats coef lm median predict
#' @importFrom igraph %du% ecount degree vcount
#' @export
ggplot2::autoplot
NULL

#' @docType package
#' @aliases NULL graphonmix-package
#' @keywords internal
"_PACKAGE"

# The following block is used by usethis to automatically manage
# roxygen namespace tags. Modify with care!
## usethis namespace: start
## usethis namespace: end
NULL
